
# pandemaniac
CS144 Pandemaniac Visualizer! 10,000 nodes requires a good deal of patience, 5,000 a moderate amount of patience, and 2,000 a modicum of patience.

````python
git clone https://github.com/atisor73/pandemaniac
cd pandemaniac/
python setup.py install
````

<br>

Here is a demonstration of a 9-player coloring:

```
import pandemaniac
pandemaniac.viz(G, [seed1, seed2, ... ])
```



<img src="_imgs/patrol.gif" width=60%>














